@@ -570,12 +570,13 @@ void wxStfParentFrame::OnAbout(wxCommandEvent& WXUNUSED(event) )
 
     wxString(wxT("Documentation:\n\
     Jose Guzman\n\n\
-    Event detection by template matching:\n\
+    Event detection algorithms:\n\
     Jonas, P., Major, G. & Sakmann B. (1993) J Physiol 472:615-63\n\
-    Clements, J. D. & Bekkers, J. M. (1997) Biophys J 73:220-229\n\n\
+    Clements, J. D. & Bekkers, J. M. (1997) Biophys J 73:220-229\n\
+    Pernía-Andrade,  A.J., et al., (2012) Biophys J 103:1429-39.\n\n\
     Thanks to Bill Anderson (www.winltp.com) for helpful suggestions"));
 	info.SetDescription(about);
-	info.SetCopyright(wxT("(C) 2001-2013 Christoph Schmidt-Hieber <christsc@gmx.de>\n\
+	info.SetCopyright(wxT("(C) 2001-2015 Christoph Schmidt-Hieber <christsc@gmx.de>\n\
     Christoph Schmidt-Hieber, University College London\n\
     Published under the GNU general public license (http://www.gnu.org/licenses/gpl.html)"));
 
